@@ -175,12 +175,16 @@ const NSString *BayerProcessedDarktKey = @"procDark";
                               pixelValue = (double)(imageSegment[yl-by+1][p][xl-bx]);
                               otherWeight = (double)weightSegment[yl-by+1][p][xl-bx]/_accumulations;
                            }
-                           double interpolationWeight = otherWeight - localWeight;
-                           
-                           if (interpolationWeight > 0.0)
+
+                           if (otherWeight > 0.0)
                            {
-                              sum += (pixelValue / otherWeight) * interpolationWeight;
-                              weight += interpolationWeight;
+                              double interpolationWeight = otherWeight - localWeight;
+
+                              if (interpolationWeight > 0.0)
+                              {
+                                 sum += (pixelValue / otherWeight) * interpolationWeight;
+                                 weight += interpolationWeight;
+                              }
                            }
                         }
                      }
