@@ -915,7 +915,7 @@ static BOOL isWaitingConversion = NO;
  */
 - (void) getImageSample:(REAL * const * const)sample
              withPlanes:(u_short)nPlanes
-                    atX:(u_short)x Y:(u_short)y W:(u_short)w H:(u_short)h
+                    atX:(short)x Y:(short)y W:(u_short)w H:(u_short)h
               lineWidth:(u_short)lineW
 {
    const double scale = (_numberOfPlanes == 1 ? 1.0 : 1.0/256.0);
@@ -961,7 +961,7 @@ static BOOL isWaitingConversion = NO;
    return( (NSDictionary*)_metadata );
 }
 
-- (LynkeosImageBuffer*) getCustomImageSampleAtX:(u_short)x Y:(u_short)y 
+- (LynkeosImageBuffer*) getCustomImageSampleAtX:(short)x Y:(short)y 
                                                   W:(u_short)w H:(u_short)h
                                       withTransform:(NSAffineTransformStruct)transform
                                         withOffsets:(const NSPoint*)offsets
