@@ -311,7 +311,7 @@
 
 - (void) getImageSample:(REAL * const * const)sample
              withPlanes:(u_short)nPlanes
-                    atX:(u_short)x Y:(u_short)y W:(u_short)w H:(u_short)h
+                    atX:(short)x Y:(short)y W:(u_short)w H:(u_short)h
               lineWidth:(u_short)lineW
 {
    u_short xs, ys, yl;
