@@ -168,7 +168,7 @@ static int colorSelector(void *opaque, u_short x, u_short y)
       _bytesPerRow = libraw_data->sizes.raw_pitch;
       _height = _yLimit - _yOrigin;
       if (libraw_data->color.maximum > 0)
-         _scale = 255.0 / (double)libraw_data->color.maximum;
+         _scale = 256.0 / (double)libraw_data->color.maximum;
 
       // Retrieve metadata
       if (strnlen(libraw_data->other.artist, 64) != 0)
@@ -460,7 +460,7 @@ static int colorSelector(void *opaque, u_short x, u_short y)
 
 - (void) getImageSample:(REAL * const * const)sample
              withPlanes:(u_short)nPlanes
-                    atX:(u_short)x Y:(u_short)y W:(u_short)w H:(u_short)h
+                    atX:(short)x Y:(short)y W:(u_short)w H:(u_short)h
               lineWidth:(u_short)lineW
 {
    const NSAffineTransformStruct ident = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
@@ -470,7 +470,7 @@ static int colorSelector(void *opaque, u_short x, u_short y)
    [customImage convertToPlanar:sample withPlanes:nPlanes lineWidth:lineW];
 }
 
-- (LynkeosImageBuffer*) getCustomImageSampleAtX:(u_short)x Y:(u_short)y
+- (LynkeosImageBuffer*) getCustomImageSampleAtX:(short)x Y:(short)y
                                               W:(u_short)w H:(u_short)h
                                   withTransform:(NSAffineTransformStruct)transform
                                     withOffsets:(const NSPoint*)offsets
@@ -507,7 +507,7 @@ static int colorSelector(void *opaque, u_short x, u_short y)
          if (tp.y < 0.0)
             tp.y = 0.0;
          else if (tp.y > (_height - 1))
-            tp.x = _height - 1;
+            tp.y = _height - 1;
 
          if (tp.x < bottomLeft.x)
             bottomLeft.x = floor(tp.x);
@@ -537,7 +537,7 @@ static int colorSelector(void *opaque, u_short x, u_short y)
          {
             void *pixPtr = linePtr + (xl+_xOrigin)*sizeof(u_short);
 
-            v = (REAL)(((uint16*)pixPtr)[0])/256.0;
+            v = (REAL)(((uint16*)pixPtr)[0])*_scale;
             v *= _whiteBalance[colorSelector(libraw_data, xl, yl)];
             imageData[xl-bottomLeft.x+newW*(yl-bottomLeft.y)] = v;
          }
