@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Mar 07 2005.
-//  Copyright (c) 2005-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2005-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -522,7 +522,7 @@ static const ArithmeticOperation_t Scale_Spectrum
    // Copy line by line, as the padding may differ between original and copy
    for (int p = 0; p < buf->_nPlanes; p++)
       for (int y = 0; y < buf->_h; y++)
-         memcpy( buf->_planes[p] + y*buf->_padw, _planes[p] + y*_padw, sizeof(REAL)*buf->_w );
+         memcpy( buf->_planes[p] + y*buf->_padw, _planes[p] + y*_padw, sizeof(REAL)*buf->_padw );
    buf->_isSpectrum = _isSpectrum;
 
    return( buf );
