@@ -363,6 +363,15 @@ static NSString * const K_PLANELEVELS_SET_KEY = @"planeLevelsSet";
                      forRect:(LynkeosIntegerRect)rect
               prepareInverse:(BOOL)prepareInverse
 {
+   if (_nPlanes == 0 || rect.size.width == 0 || rect.size.height == 0)
+   {
+      // There is no image, therefore no spectrum
+      if (*buffer != nil)
+         [*buffer release];
+      *buffer = nil;
+      return;
+   }
+
    if ( _processedSpectrum != nil && rect.origin.x == 0 && rect.origin.y == 0
         && rect.size.width == _size.width && rect.size.height == _size.height
         && *buffer == nil )
@@ -370,7 +379,7 @@ static NSString * const K_PLANELEVELS_SET_KEY = @"planeLevelsSet";
 
    else
    {
-      // Allocate a buffer if needed
+      // Allocate a Fourier buffer if needed
       if ( *buffer == nil )
          *buffer = [[[LynkeosFourierBuffer alloc]
                      initWithNumberOfPlanes:_nPlanes
@@ -392,30 +401,41 @@ static NSString * const K_PLANELEVELS_SET_KEY = @"planeLevelsSet";
 
 - (void) setFourierTransform:(LynkeosFourierBuffer*)buffer
 {
-   NSAssert( buffer != nil, @"Invalid nil Fourier buffer" );
-
    if ( _processedImage != nil && _processedImage != _originalImage )
       [_processedImage release];
    _processedImage = nil;
-   [buffer retain];
-   [buffer setOperatorsStrategy:_strategy];
+   if (buffer != nil)
+   {
+      [buffer retain];
+      [buffer setOperatorsStrategy:_strategy];
+   }
    if ( _processedSpectrum != nil )
       [_processedSpectrum release];
    _processedSpectrum = buffer;
    _imageSequenceNumber++;
-   _size.width = _processedSpectrum->_w;
-   _size.height = _processedSpectrum->_h;
-   if ( _nPlanes != _processedSpectrum->_nPlanes )
+   if (_processedSpectrum != nil)
    {
+      _size.width = _processedSpectrum->_w;
+      _size.height = _processedSpectrum->_h;
+      if ( _nPlanes != _processedSpectrum->_nPlanes )
+      {
+         [self freeRenderParameters];
+
+         _nPlanes = _processedSpectrum->_nPlanes;
+
+         _black = (double*)malloc( (_nPlanes+1)*sizeof(double) );
+         _white = (double*)malloc( (_nPlanes+1)*sizeof(double) );
+         _gamma = (double*)malloc( (_nPlanes+1)*sizeof(double) );
+
+         [self resetRenderParameters];
+      }
+   }
+   else
+   {
+      _size.width = 0;
+      _size.height = 0;
+      _nPlanes = 0;
       [self freeRenderParameters];
-
-      _nPlanes = _processedSpectrum->_nPlanes;
-
-      _black = (double*)malloc( (_nPlanes+1)*sizeof(double) );
-      _white = (double*)malloc( (_nPlanes+1)*sizeof(double) );
-      _gamma = (double*)malloc( (_nPlanes+1)*sizeof(double) );
-
-      [self resetRenderParameters];
    }
 
    // Notify for some change
