@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sun Nov 5 2006.
-//  Copyright (c) 2006-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2006-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -244,12 +244,18 @@ extern NSString * const LynkeosImageViewZoomDidChangeNotification;
 
 /*!
  * @abstract Image view is being redrawn.
- * @discussion The object is the image view. There is no user info.<br>
+ * @discussion The object is the image view. The dictionary contains the redrawn rectangle.<br>
  *    Processing views can use this notification to add drawings in the image
  *    view
  * @ingroup Notifications
  */
 extern NSString * const LynkeosImageViewRedrawNotification;
+
+/*!
+ * @abstract User info key for the selection index range.
+ * @ingroup Notifications
+ */
+extern NSString * const LynkeosImageViewRedrawRect;
 //@}
 
 /*!
