@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Tue Sep 30, 2003.
-//  Copyright (c) 2003-2020. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2023. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -502,8 +502,8 @@ static NSComparisonResult compareReaders( id obj1, id obj2, void *ctx )
 
             NSURL *baseURL = [NSURL fileURLWithPath:basePath];
             NSString *relURL =
-               [relativePath stringByAddingPercentEscapesUsingEncoding:
-                                                          NSUTF8StringEncoding];
+            [relativePath stringByAddingPercentEncodingWithAllowedCharacters:
+                             [NSCharacterSet URLPathAllowedCharacterSet]];
             itemRelativeURL = [NSURL URLWithString:relURL
                                       relativeToURL:baseURL];
          }
@@ -951,8 +951,8 @@ static NSComparisonResult compareReaders( id obj1, id obj2, void *ctx )
          {
             // We need a temporary buffer to read in
             data = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:readPlanesNb
-                                                                       width:wRect.size.width
-                                                                      height:wRect.size.height];
+                                                               width:wRect.size.width
+                                                              height:wRect.size.height];
             readPlanes = [(LynkeosImageBuffer*)data colorPlanes];
          }
 
@@ -988,8 +988,8 @@ static NSComparisonResult compareReaders( id obj1, id obj2, void *ctx )
 
 - (void) getImageSample:(LynkeosImageBuffer**)buffer
                  inRect:(LynkeosIntegerRect)rect
-          withTransform:(NSAffineTransformStruct)transform
-            withOffsets:(NSPoint *)offsets
+          withTransform:(const NSAffineTransformStruct)transform
+            withOffsets:(const NSPoint *)offsets
 {
    int i;
    Class interpolatorClass = [LynkeosInterpolatorManager interpolatorWithScaling:UseTransform
@@ -1053,8 +1053,8 @@ static NSComparisonResult compareReaders( id obj1, id obj2, void *ctx )
 }
 
 - (LynkeosImageBuffer*) getCustomImageSampleinRect:(LynkeosIntegerRect)rect
-                                         withTransform:(NSAffineTransformStruct)transform
-                                           withOffsets:(NSPoint *)offsets
+                                         withTransform:(const NSAffineTransformStruct)transform
+                                           withOffsets:(const NSPoint *)offsets
 {
    LynkeosImageBuffer* customImage = nil;
 
