@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Jun 21 2007.
-//  Copyright (c) 2007-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -499,7 +499,8 @@ static NSString * const K_STACK_NAME = @"name";
    if ( [_normalizeCheckBox state] != state)
       [_normalizeCheckBox setState:state];
    [_doubleSizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
-   [_monochromeCheckBox setEnabled:(data == ListData && mode == FlatFieldMode)];
+   [_monochromeCheckBox setEnabled:(data == ListData && mode == FlatFieldMode
+                                    && [[list imageArray] count] != 0)];
    [_normalizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
 
    Stack_Mode_t s_mode = (params->_stackMethod != Stacking_Calibration
@@ -525,7 +526,7 @@ static NSString * const K_STACK_NAME = @"name";
          NSAssert( NO, @"Invalid stacking method" );
    }
 
-   [_stackButton setEnabled:(data == ListData
+   [_stackButton setEnabled:((data == ListData || [[list imageArray] count] == 0)
                              && params->_cropRectangle.size.width != 0
                              && params->_cropRectangle.size.height != 0)];
 
@@ -701,6 +702,14 @@ static NSString * const K_STACK_NAME = @"name";
                       selector:@selector(listChanged:)
                           name: LynkeosListChangeNotification
                         object:_document];
+      [notifCenter addObserver:self
+                selector:@selector(listChanged:)
+                    name: LynkeosItemAddedNotification
+                  object:_document];
+      [notifCenter addObserver:self
+                selector:@selector(listChanged:)
+                    name: LynkeosItemRemovedNotification
+                  object:_document];
       [notifCenter addObserver:self
                       selector:@selector(dataModeChanged:)
                           name: LynkeosDataModeChangeNotification
@@ -740,6 +749,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
                  [list getProcessingParameterWithRef:myImageStackerParametersRef
                                        forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
 
    params->_cropRectangle.origin.x = [_cropX doubleValue];
    params->_cropRectangle.origin.y = [_cropY doubleValue];
@@ -766,6 +776,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
    const NSAffineTransformStruct oldT = [params->_transform transformStruct];
    const CGFloat factor = ([_doubleSizeCheckBox state] == NSOnState ? 2.0 : 1.0 );
    const CGFloat oldF2 = oldT.m11*oldT.m22 - oldT.m12*oldT.m21;
@@ -801,6 +812,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
 
    params->_monochromeStack = ([_monochromeCheckBox state] == NSOnState);
 
@@ -815,6 +827,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
 
    params->_normalized = ([_normalizeCheckBox state] == NSOnState);
 
@@ -829,6 +842,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
 
    params->_stackMethod = (Stack_Mode_t)[sender selectedTag];
 
@@ -865,6 +879,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
    params->_method.sigma.threshold = v;
    [list setProcessingParameter:params
                         withRef:myImageStackerParametersRef
@@ -877,6 +892,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params =
       [list getProcessingParameterWithRef:myImageStackerParametersRef
                             forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Update of non existent stacking parameters" );
    params->_method.extremum.maxValue = ([sender selectedRow] == 1);
    [list setProcessingParameter:params
                         withRef:myImageStackerParametersRef
@@ -891,6 +907,7 @@ static NSString * const K_STACK_NAME = @"name";
    MyImageStackerParameters *params=
                  [list getProcessingParameterWithRef:myImageStackerParametersRef
                                        forProcessing:myImageStackerRef];
+   NSAssert( params != nil, @"Stacking without stacking parameters" );
    ListMode_t mode = [_document listMode];
 
    [sender setEnabled:NO];
