@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Sep 24 2003.
-//  Copyright (c) 2003-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -748,7 +748,10 @@ static const double MM_LN_10 = -M_LN10;
 
    // Give an opportunity to add drawings
    [[NSNotificationCenter defaultCenter] postNotificationName: LynkeosImageViewRedrawNotification
-                                                       object: self];
+                                                       object: self
+                                                     userInfo:
+                                                        [NSDictionary dictionaryWithObject:[NSValue valueWithRect:rect]
+                                                                                    forKey:LynkeosImageViewRedrawRect]];
 }
 
 - (NSSize) imageSize { return( _canvasRect.size ); }
