@@ -439,7 +439,7 @@
 
 - (void) getImageSample:(REAL * const * const)sample atIndex:(u_long)index
              withPlanes:(u_short)nPlanes
-                    atX:(u_short)x Y:(u_short)y W:(u_short)w H:(u_short)h
+                    atX:(short)x Y:(short)y W:(u_short)w H:(u_short)h
               lineWidth:(u_short)lineW
 {
    const NSAffineTransformStruct ident = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
@@ -450,7 +450,7 @@
 }
 
 - (LynkeosImageBuffer*) getCustomImageSampleAtIndex:(u_long)index
-                                                    atX:(u_short)x Y:(u_short)y
+                                                    atX:(short)x Y:(short)y
                                                       W:(u_short)w H:(u_short)h
                                           withTransform:(NSAffineTransformStruct)transform
                                             withOffsets:(const NSPoint*)offsets
